@@ -11,7 +11,7 @@ The config is only retrieved once
 config = None
 
 @pytest.hookimpl(hookwrapper=True)
-def pytest_runtest_makereport(item, call, __multicall__):
+def pytest_runtest_makereport(item, call):
     outcome = yield
     report = outcome.get_result()
     if report.when == "call":
